@@ -1,9 +1,8 @@
 package Bundle::CCMS;
 use strict;
 use warnings;
-use vars qw($VERSION);
 
-$VERSION = sprintf '%d.%03d', q$Revision: 1.3 $ =~ /(\d+)/g;
+$VERSION = '1.02';
 
 1;
 
@@ -35,8 +34,6 @@ Config::Tiny
 
 Data::Serializer
 
-XML::Dumper          - required by recent versions of Data::Dumper
-
 Data::Dumper
 
 DBI
@@ -45,8 +42,6 @@ File::Spec
 
 File::Basename
 
-File::Type
-
 FreezeThaw
 
 Getopt::Long
